function sfc_prep,index,data,image, index_out=index_out

;+
; NAME
;	sfc_prep
; PURPOSE
;	To prepare a smoothed SFC image for straylight correction.
; CALLING SEQUENCE
;	sfc_image = sfc_prep(sft_index,sft_data,image)
; INPUT
;	sft_index   -index structure for selected SFT image
;	sft_data    -selected SFT image
; OUTPUT
;	Smoothed SFC image (floating point).
; OPTIONAL OUTPUT
;	image	    - dark corrected input image
;       index_out   - index of the dark corrected image
; PROCEDURE
;	1.  Dark_sub with /dc_intepolate
;	2.  Smooth with SFC_DE_SPIKER (median filter)
;	3.  Choose width for boxcar-average smoothing
;	4.  Boxcar-average smooth with BIG_SMOOTH
; RESTRICTIONS
;	Can only process one image at a time
;	Slow -- takes about 1 minutes to process one image on MIPS machine.
;	Calls LWA/ucon programs SFC_DE_SPIKER and BIG_SMOOTH.
; HISTORY
;	LWA, 11-Dec-94  Written
;	LWA, 18-Dec-94  Took out one despike and added variable
;		smoothing width -- based on tests with Al.1
;		and added image keyword
;	LWA, 20-Dec-94, Added test for ND filter for smoothing.
;	SLF, 18-nov-95, SLF, Add Al.1 grill correction per LWA
;       NN,   7-Aug-97, Added index_out from dark_sub
;-

; print,sxt_decomp(byte(min(data))),sxt_decomp(byte(max(data)))
; Subtract dark signal from straylight image.

out=dark_sub(index,data, index_out, /dc_interpolate,/float)
image=fix(out)

; print,'Dark_sub done
; pmm,out
; print,'Smoothing is under way -- be patient.

; First stage smoothing and despike of straylight image.

out=sfc_de_spiker(out,3)
; pmm,out

;  Set boxcar smoothing width and smooth straylight image

 width=fix(10^(1.391946-0.0010278969*(max(out)))+0.5)
 if width lt 3 then width=3
 if (gt_filta(index) eq 6 and gt_res(index) eq 1) then width=8
 if (gt_filta(index) eq 6 and gt_res(index) eq 2) then width=4
; print,"Smoothing width = ", + width

out=big_smooth(out,width)
; pmm,out
; print

;;;;;;;;;;;;;;;;; NEW AL.1 GRILL CORRECTION STUFF

if int2secarr(index,(get_yo_dates(/ent))(2)) gt 0. AND	$	 ; after 2nd ent.
   (gt_filta(index) eq 1) and (gt_filtb(index) eq 2) then begin  ; Al.1/open
   grill_file=concat_dir('$DIR_SXT_CALIBRATE','al1_grill.genx')	 ; grill file
   if file_exist(grill_file) then begin
      restgen,file=grill_file,gindex,grill			 ; read grill
      prstr,strjustify(["% sfc_prep: Applying GRILL correction for:", $
         get_info(index,/non)],/box)
      out=out+(grill*(gt_expdur(index)/2.668e3))      
   endif else message,/info,"Cannot find Al.1 grill file: " + grill_file
endif
;;;;;;;;;;;;;;;;; END OF GRILL CORRECTION STUFF

return,out

end

